@@ -18,19 +18,13 @@ Log::Handler::Levels - All levels for Log::Handler.
 
 =item B<warning()>
 
-=item B<error()>
+=item B<error()>, B<err()>
 
-=item B<err()>
-
-=item B<critical()>
-
-=item B<crit()>
+=item B<critical()>, B<crit()>
 
 =item B<alert()>
 
-=item B<emergency()>
-
-=item B<emerg()>
+=item B<emergency()>, B<emerg()>
 
 =back
 
@@ -46,19 +40,13 @@ Log::Handler::Levels - All levels for Log::Handler.
 
 =item B<is_warning()>
 
-=item B<is_error()>
+=item B<is_error()>, B<is_err()>
 
-=item B<is_err()>
-
-=item B<is_critical()>
-
-=item B<is_crit()>
+=item B<is_critical()>, B<is_crit()>
 
 =item B<is_alert()>
 
-=item B<is_emergency()>
-
-=item B<is_emerg()>
+=item B<is_emergency()>, B<is_emerg()>
 
 =back
 
@@ -78,13 +66,15 @@ Check if one of the levels C<critical> - C<emergency> is active.
 
 =head2 Log and trace
 
-These methods are useful if you want to add a full backtrace to your message.
+These methods are useful if you want to add a full backtrace to
+your message.
 
-Maybe you like do something like
+Maybe you want to intercept unexpected errors and want to know
+who called C<die()>.
 
     $SIG{__DIE__} = sub { $log->fatal_and_trace(@_) };
 
-Or just if you want to know who called who
+Or maybe you just want to know who called who
 
     $log->info_and_trace('who called who');
 
@@ -98,19 +88,13 @@ Or just if you want to know who called who
 
 =item B<warning_and_trace()>
 
-=item B<error_and_trace()>
+=item B<error_and_trace()>, B<err_and_trace()>
 
-=item B<err_and_trace()>
-
-=item B<critical_and_trace()>
-
-=item B<crit_and_trace()>
+=item B<critical_and_trace()>, B<crit_and_trace()>
 
 =item B<alert_and_trace()>
 
-=item B<emergency_and_trace()>
-
-=item B<emerg_and_trace()>
+=item B<emergency_and_trace()>, B<emerg_and_trace()>
 
 =item B<fatal_and_trace()>
 
@@ -125,6 +109,9 @@ The default exit code is 1
 Pass the exit code yourself
 
     $log->error_and_exit(9 => 'an error happends')
+
+    # or
+
     $log->info_and_exit(0 => 'program stopped')
 
 Note that if the first argument is a number then this number is used
@@ -140,83 +127,68 @@ as exit code.
 
 =item B<warning_and_exit()>
 
-=item B<error_and_exit()>
+=item B<error_and_exit()>, B<err_and_exit()>
 
-=item B<err_and_exit()>
-
-=item B<critical_and_exit()>
-
-=item B<crit_and_exit()>
+=item B<critical_and_exit()>, B<crit_and_exit()>
 
 =item B<alert_and_exit()>
 
-=item B<emergency_and_exit()>
-
-=item B<emerg_and_exit()>
+=item B<emergency_and_exit()>, B<emerg_and_exit()>
 
 =item B<fatal_and_exit()>
 
 =back
 
-=head2 Log and die methods
+=head2 Log and die
 
-Log the message to the output and execute C<Carp::croak()>.
+These methods log the message to the output and then call C<Carp::croak()>.
 
 =over
 
-=item B<error_and_die()>
+=item B<error_and_die()>, B<err_and_die()>
 
-=item B<err_and_die()>
-
-=item B<critical_and_die()>
-
-=item B<crit_and_die()>
+=item B<critical_and_die()>, B<crit_and_die()>
 
 =item B<alert_and_die()>
 
-=item B<emergency_and_die()>
-
-=item B<emerg_and_die()>
+=item B<emergency_and_die()>, B<emerg_and_die()>
 
 =item B<fatal_and_die()>
 
 =back
 
-=head2 Log and croak methods
+=head2 Log and croak
 
-Log the message to the output and execute C<Carp::croak()> with C<CarpLevel+3>.
+These methods log the message to the output and then call C<Carp::croak()>
+with C<CarpLevel+3>
 
 =over
 
-=item B<error_and_croak()>
+=item B<error_and_croak()>, B<err_and_croak()>
 
-=item B<err_and_croak()>
-
-=item B<critical_and_croak()>
-
-=item B<crit_and_croak()>
+=item B<critical_and_croak()>, B<crit_and_croak()>
 
 =item B<alert_and_croak()>
 
-=item B<emergency_and_croak()>
-
-=item B<emerg_and_croak()>
+=item B<emergency_and_croak()>, B<emerg_and_croak()>
 
 =item B<fatal_and_croak()>
 
 =back
 
-=head2 Log and warn methods
+=head2 Log and warn/carp
 
 =over
 
-=item B<carp()>
-
-    Log the message as warning to the output and execute C<Carp::carp> with C<CarpLevel+3>.
-
 =item B<warn()>
 
-    Log the message as warning to the output and execute C<Carp::carp>.
+This method log the message as warning to the output and then call
+C<Carp::carp>.
+
+=item B<carp()>
+
+This method log the message as warning to the output and then call
+C<Carp::carp> with C<CarpLevel+3>.
 
 =back
 
@@ -249,7 +221,7 @@ package Log::Handler::Levels;
 
 use strict;
 use warnings;
-our $VERSION  = '0.00_01';
+our $VERSION  = '0.00_03';
 use Carp qw();
 
 my %LEVELS_BY_ROUTINE = (
